summaryrefslogtreecommitdiffstats
path: root/src/customtraylabel.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/customtraylabel.cpp')
-rw-r--r--src/customtraylabel.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/customtraylabel.cpp b/src/customtraylabel.cpp
index a657a89..e27dbba 100644
--- a/src/customtraylabel.cpp
+++ b/src/customtraylabel.cpp
@@ -36,7 +36,7 @@
#include "trace.h"
#include "customtraylabel.h"
#include "traylabelmgr.h"
-#include "kdocker.h"
+#include "tdedocker.h"
CustomTrayLabel::CustomTrayLabel(Window w, TQWidget* p, const TQString& t)
: TQTrayLabel(w, p, t), mUndockWhenDead(false)
@@ -56,9 +56,9 @@ CustomTrayLabel::CustomTrayLabel(const TQStringList& argv, pid_t pid,
*/
void CustomTrayLabel::installMenu()
{
- //TQPixmap kdocker_png(TDEGlobal::iconLoader()->loadIcon("kdocker", TDEIcon::NoGroup, TDEIcon::SizeSmall));
- TQPixmap *kdocker_png = new TQPixmap("kdocker");
- setIcon(*kdocker_png);
+ //TQPixmap tdedocker_png(TDEGlobal::iconLoader()->loadIcon("tdedocker", TDEIcon::NoGroup, TDEIcon::SizeSmall));
+ TQPixmap *tdedocker_png = new TQPixmap("tdedocker");
+ setIcon(*tdedocker_png);
TrayLabelMgr *tlMgr = TrayLabelMgr::instance();
mOptionsMenu = new TQPopupMenu(this);
@@ -106,8 +106,8 @@ void CustomTrayLabel::installMenu()
mSkipTaskbar->addTo(mOptionsMenu);
mMainMenu = new TQPopupMenu(this);
- mMainMenu->insertItem(TQIconSet(*kdocker_png),
- i18n("About KDocker"), tlMgr, SLOT(about()));
+ mMainMenu->insertItem(TQIconSet(*tdedocker_png),
+ i18n("About TDEDocker"), tlMgr, SLOT(about()));
mMainMenu->insertSeparator();
mMainMenu->insertItem(i18n("Options"), mOptionsMenu);
mMainMenu->insertItem(i18n("Dock Another"), tlMgr, SLOT(dockAnother()));
@@ -215,7 +215,7 @@ void CustomTrayLabel::setCustomIcon(void)
if (icon.isNull()) return; // user cancelled
if (!TQPixmap(icon).isNull()) break;
TRACE("Attempting to set icon to %s", icon.latin1());
- TQMessageBox::critical(this, i18n("KDocker"),
+ TQMessageBox::critical(this, i18n("TDEDocker"),
i18n("%1 is not a valid icon").arg(icon));
}
@@ -226,7 +226,7 @@ void CustomTrayLabel::setCustomIcon(void)
void CustomTrayLabel::slotSetBalloonTimeout(void)
{
bool ok;
- int timeout = TQInputDialog::getInteger(i18n("KDocker"),
+ int timeout = TQInputDialog::getInteger(i18n("TDEDocker"),
i18n("Enter balloon timeout (secs). 0 to disable ballooning"),
balloonTimeout()/1000, 0, 60, 1, &ok);
@@ -259,7 +259,7 @@ void CustomTrayLabel::slotSetLaunchOnStartup()
}
// Request user to provide file name himself
- if (TQMessageBox::critical(NULL, i18n("KDocker"),
+ if (TQMessageBox::critical(NULL, i18n("TDEDocker"),
i18n("\"%1\" is not a valid executable "
"or was not found in your $PATH").arg(app),
i18n("Select program"), i18n("Cancel")) == 1)
@@ -331,8 +331,8 @@ void CustomTrayLabel::processDead(void)
{
/*
* This is a ugly hack but worth every but of ugliness IMO ;).
* Lets say, an instance of xmms, already exists. You type kdocker xmms.
* KDocker launches xmms. xmms cowardly exists seeing its previous instance.
* Wouldnt it be nice now to dock the previous instance of xmms automatically.
* This is more common than you think (think of session restoration)
*/
@@ -356,7 +356,7 @@ bool CustomTrayLabel::canDockWindow(Window w)
void CustomTrayLabel::dropEvent(TQDropEvent *)
{
- TQMessageBox::information(NULL, "KDocker",
+ TQMessageBox::information(NULL, "TDEDocker",
i18n("You cannot drop an item into the tray icon. Drop it on the window\n"
"that is brought in front when you hover the item over the tray icon"));
}
@@ -331,8 +331,8 @@ void CustomTrayLabel::processDead(void)
/*
* This is a ugly hack but worth every but of ugliness IMO ;).
- * Lets say, an instance of xmms, already exists. You type kdocker xmms.
- * KDocker launches xmms. xmms cowardly exists seeing its previous instance.
+ * Lets say, an instance of xmms, already exists. You type tdedocker xmms.
+ * TDEDocker launches xmms. xmms cowardly exists seeing its previous instance.
* Wouldnt it be nice now to dock the previous instance of xmms automatically.
* This is more common than you think (think of session restoration)